@@ -831,15 +831,15 @@ def _head_object(context, bucket, key):
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
                              aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
     try:
-        response = yield s3_client.head_object(Bucket=bucket, Key=key)
-        print('head',response)
-        if 'ContentLength' in response and response['ContentLength'] >= 0:
+        response = yield s3_client.list_objects_v2(
+        Bucket=bucket,
+        Prefix=key,
+        )
+    for obj in response.get('Contents', []):
+        if obj['Key'] == key:
             return True
-        else:
-            return False
-    except ClientError as exc:
-        if exc.response['Error']['Code'] != '404':
-            raise
+    return False
+
 
 
 @gen.coroutine
